@@ -130,10 +130,10 @@ class LXDContainerImage(object):
                 raise exception.ImageUnacceptable(image_id=instance.image_ref,
                                                   reason=reason)
 
-            if disk_format != 'raw':
+            if disk_format not in ['raw', 'root-tar']:
                 reason = _('nova-lxd does not support images in %s format. '
-                           'You should upload an image in raw format.') % \
-                    disk_format
+                           'You should upload an image in raw or root-tar '
+                           'format.') % disk_format
                 raise exception.ImageUnacceptable(image_id=instance.image_ref,
                                                   reason=reason)
         except Exception as ex:
